@@ -38,8 +38,11 @@ ASTFunc = Callable[[State, AST_T, ast.AST], Iterable[Tuple[Offset, TokenFunc]]]
 
 RECORD_FROM_IMPORTS = frozenset((
     '__future__',
+    'asyncio',
+    'collections',
     'functools',
     'mmap',
+    'os',
     'select',
     'six',
     'six.moves',
