@@ -25,19 +25,13 @@ def _find_if_else_block(tokens: list[Token], i: int) -> tuple[Block, Block]:
     return if_block, else_block
 
 
-def _find_elif(tokens: list[Token], i: int) -> int:
-    while tokens[i].src != 'elif':  # pragma: no cover (only for <3.8.1)
-        i -= 1
-    return i
-
-
 def _fix_py3_block(i: int, tokens: list[Token]) -> None:
     if tokens[i].src == 'if':
         if_block = Block.find(tokens, i)
         if_block.dedent(tokens)
         del tokens[if_block.start:if_block.block]
     else:
-        if_block = Block.find(tokens, _find_elif(tokens, i))
+        if_block = Block.find(tokens, i)
         if_block.replace_condition(tokens, [Token('NAME', 'else')])
 
 
@@ -47,11 +41,24 @@ def _fix_py2_block(i: int, tokens: list[Token]) -> None:
         else_block.dedent(tokens)
         del tokens[if_block.start:else_block.block]
     else:
-        j = _find_elif(tokens, i)
-        if_block, else_block = _find_if_else_block(tokens, j)
+        if_block, else_block = _find_if_else_block(tokens, i)
         del tokens[if_block.start:else_block.start]
 
 
+def _fix_remove_block(i: int, tokens: list[Token]) -> None:
+    block = Block.find(tokens, i)
+    del tokens[block.start:block.end]
+
+
+def _fix_py2_convert_elif(i: int, tokens: list[Token]) -> None:
+    if_block = Block.find(tokens, i)
+    # wasn't actually followed by an `elif`
+    if tokens[if_block.end].src != 'elif':
+        return
+    tokens[if_block.end] = Token('CODE', tokens[i].src)
+    _fix_remove_block(i, tokens)
+
+
 def _fix_py3_block_else(i: int, tokens: list[Token]) -> None:
     if tokens[i].src == 'if':
         if_block, else_block = _find_if_else_block(tokens, i)
@@ -59,12 +66,21 @@ def _fix_py3_block_else(i: int, tokens: list[Token]) -> None:
         del tokens[if_block.end:else_block.end]
         del tokens[if_block.start:if_block.block]
     else:
-        j = _find_elif(tokens, i)
-        if_block, else_block = _find_if_else_block(tokens, j)
+        if_block, else_block = _find_if_else_block(tokens, i)
         del tokens[if_block.end:else_block.end]
         if_block.replace_condition(tokens, [Token('NAME', 'else')])
 
 
+def _fix_py3_convert_elif(i: int, tokens: list[Token]) -> None:
+    if_block = Block.find(tokens, i)
+    # wasn't actually followed by an `elif`
+    if tokens[if_block.end].src != 'elif':
+        return
+    tokens[if_block.end] = Token('CODE', tokens[i].src)
+    if_block.dedent(tokens)
+    del tokens[if_block.start:if_block.block]
+
+
 def _eq(test: ast.Compare, n: int) -> bool:
     return (
         isinstance(test.ops[0], ast.Eq) and
@@ -150,8 +166,12 @@ def visit_If(
                 )
             )
     ):
-        if node.orelse and not isinstance(node.orelse[0], ast.If):
+        if len(node.orelse) == 1 and isinstance(node.orelse[0], ast.If):
+            yield ast_to_offset(node), _fix_py2_convert_elif
+        elif node.orelse:
             yield ast_to_offset(node), _fix_py2_block
+        elif node.col_offset == 0:
+            yield ast_to_offset(node), _fix_remove_block
     elif (
             # if six.PY3:
             is_name_attr(
@@ -193,7 +213,9 @@ def visit_If(
                 )
             )
     ):
-        if node.orelse and not isinstance(node.orelse[0], ast.If):
+        if len(node.orelse) == 1 and isinstance(node.orelse[0], ast.If):
+            yield ast_to_offset(node), _fix_py3_convert_elif
+        elif node.orelse:
             yield ast_to_offset(node), _fix_py3_block_else
-        elif not node.orelse:
+        else:
             yield ast_to_offset(node), _fix_py3_block
